/*
Description:
This script will remove the FOB option from the Freight Terms option set if shipping method is Will Call.
*/

function updateFreightTerms() {
	// Set up the option set constants
	// Ensure that these match the codes in CRM
	var SHIPPINGMETHODCODE_WILLCALL = 7;
	var FREIGHTTERMSCODE_FOB = 1;
	var FREIGHTTERMSCODE_NOCHARGE = 2;

	// Gather the field references
	var shipCode = Xrm.Page.data.entity.attributes.get("address1_shippingmethodcode");
	var freightCode = Xrm.Page.data.entity.attributes.get("address1_freighttermscode");
	var freightOptionsControl = Xrm.Page.ui.controls.get("address1_freighttermscode");

	if (shipCode.getValue() == SHIPPINGMETHODCODE_WILLCALL) {
		// Default to No Charge
		freightCode.setValue(FREIGHTTERMSCODE_NOCHARGE);

		// Remove FOB as an option
		freightOptionsControl.removeOption(FREIGHTTERMSCODE_FOB);
	}
	else {
		// Default to blank
		freightCode.setValue(null);

		// First FOB as an option (if it is there) so we don't add duplicate option
		freightOptionsControl.removeOption(FREIGHTTERMSCODE_FOB);

		//Add back the FOB option
		var fobOption = new Object();
		fobOption.value = FREIGHTTERMSCODE_FOB;
		fobOption.text = "FOB";
		freightOptionsControl.addOption(fobOption, 1);
	}
}

/*
Description:
This script will remove the FOB option if shipping method is Will Call 
	and is used for the form's onload event.
*/
function removeFreightTerms() {
	// Set up the option set constants
	// Ensure that these match the codes in CRM
	var SHIPPINGMETHODCODE_WILLCALL = 7;
	var FREIGHTTERMSCODE_FOB = 1;
	var FREIGHTTERMSCODE_NOCHARGE = 2;

	var shipCode = Xrm.Page.data.entity.attributes.get("address1_shippingmethodcode");
	var freightOptions = Xrm.Page.ui.controls.get("address1_freighttermscode");

	if (shipCode.getValue() == SHIPPINGMETHODCODE_WILLCALL) {
		freightOptions.removeOption(FREIGHTTERMSCODE_FOB);
	}
}

